# Generated by Django 3.0 on 2021-09-27 06:46

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Theme',
            fields=[
                ('title', models.CharField(default='Andon管理系统', max_length=64, verbose_name='标题名称')),
                ('theme_id', models.AutoField(primary_key=True, serialize=False)),
                ('theme_color',
                 models.CharField(blank=True, default='#3dcd58', max_length=128, null=True, verbose_name='主题色')),
                ('aux_color',
                 models.CharField(blank=True, default='#696969', max_length=128, null=True, verbose_name='辅色')),
                (
                'corporate_logo', models.ImageField(max_length=300, null=True, upload_to='theme', verbose_name='LOGO')),
                ('tab_logo', models.ImageField(max_length=300, null=True, upload_to='theme', verbose_name='TAB_LOGO')),
            ],
        ),
    ]
