# Generated by Django 3.2.7 on 2021-10-04 13:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('django_theme', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='login_logo',
            field=models.ImageField(max_length=300, null=True, upload_to='theme', verbose_name='LOGIN_LOGO'),
        ),
    ]
